%             predictorcorrectorABM34.m
% Predictor: 3-stage explicit Adams-Bashforth method
% Corrector: 3-stage implicit Adams-Moulton
% The algorithm starts with two steps of the RK4 method
% f: vectorfield
% x0: initial conditions
% t0, tf: time span
% N: divisions of the time interval (timestep h=(tf-t0)/N)
function [t x] = pcABM3(f,t0,tf,x0,N)
h = (tf-t0)/N;
t=t0:h:tf; x=x0';y=x0;

[trk4 x]=rk4(@fKepler,t0,t0+2*h,x0,2);
% Initil conditions and first two steps from the RK4 method
y0 = x(1,:)'; f0 = f(t0,y0);
y1 = x(2,:)'; f1 = f(t0+h,y1);
y2 = x(3,:)'; f2 = f(t0+2*h,y2);
for i = 3:N;
 y2p = y2 + h*(23*f2 - 16*f1 + 5*f0)/12; %Predictor
 f2p = f(t0+i*h,y2p);
 y2 = y2 + h*(9*f2p + 19*f2 - 5*f1 + f0)/24; %Corrector
 f0 = f1; f1 = f2; f2= f(t0+i*h,y2); %store for next step
 x = [x ; y2'];
end

